@@ -7,7 +7,7 @@ import pandas as pd
 from pandas.api.types import is_datetime64_ns_dtype
 
 import dask.dataframe as dd
-from dask.dataframe._compat import PANDAS_GT_100
+from dask.dataframe._compat import PANDAS_GT_100, PANDAS_VERSION
 from dask.dataframe.utils import (
     assert_eq,
     assert_dask_graph,
@@ -548,6 +548,10 @@ def test_scalar_arithmetics_with_dask_instances():
     assert_eq(result, pdf + e)
 
 
+@pytest.mark.xfail(
+    PANDAS_VERSION == "1.0.2",
+    reason="https://github.com/pandas-dev/pandas/issues/32685",
+)
 def test_frame_series_arithmetic_methods():
     pdf1 = pd.DataFrame(
         {
@@ -1363,3 +1367,16 @@ def test_empty_df_reductions(func):
     ddf = dd.from_pandas(pdf, npartitions=1)
 
     assert_eq(dsk_func(ddf), pd_func(pdf))
+
+
+@pytest.mark.parametrize("method", ["sum", "prod"])
+@pytest.mark.parametrize("min_count", [0, 9])
+def test_series_agg_with_min_count(method, min_count):
+    df = pd.DataFrame([[1]], columns=["a"])
+    ddf = dd.from_pandas(df, npartitions=1)
+    func = getattr(ddf["a"], method)
+    result = func(min_count=min_count).compute()
+    if min_count == 0:
+        assert result == 1
+    else:
+        assert result is np.nan
